@@ -1,4 +1,3 @@
-import render as rd
 import os
 import importlib
 import re
@@ -17,13 +16,14 @@ def extract_function(urls_content, url):
     return False
 
 def get_view(url, project_name):
+    print("Still no problem")
     views_path = os.path.join(project_name, "urls.py")
     if not os.path.exists(views_path):
         return False
     
     with open(views_path, "r") as f:
         contents = f.read()
-    
+    print("Still no problem")
     class_name = extract_function(contents, url)
 
     views_module = importlib.import_module("{}.views".format(project_name))
@@ -34,6 +34,7 @@ def get_view(url, project_name):
 
 def handle_request(project_name, path, method, form):
     # Handle the root route
+    print("No problem")
     response_body = get_view(path, project_name)
 
     if not response_body:
